@@ -43,8 +43,10 @@ class Domoticz(IPlugin):
 		log.msg("index :  %s" % (idex))		
 		for rs in self.configuration_plugin['param_dz']:
 			if rs['ids'] == idex :
+				log.msg("index trouvé :  %s" % (idex))
 				bodies == rs['boy']
 				resp = requests.get ('http://192.168.0.3:8080/json.htm?type=command&param=switchlight&idx=%02d&switchcmd=%s&level=0' % (rs['idx'],on_off.capitalize()))
+				log.msg("resp  :  %s" % (resp))
 		return {"plugin": "Domoticz",
 			"method": "switchlight",
 			"body": bodies
